package SOCC::nagios_logwatch::Tail::File;

use 5.006001;
use strict;
use warnings;
use fields qw(_state _fh _eof_count_max _eof_count);

use File::stat;
use IO::File;
use SOCC::nagios_logwatch::Tail::FileState;



sub new {
	my ($class, $state, $eof_count_max) = @_;
	
	my $self = fields::new($class);
	$self->{_state} = $state;
	$self->{_eof_count_max} = $eof_count_max;
	$self->{_eof_count} = 0;
	
	return $self;
}



sub read_line {
	my ($self) = @_;
	my $line;
	
	if (! $self->{_fh}) {
		$self->{_fh} = IO::File->new("<" . $self->{_state}->path);
	}
	if ($self->{_fh}) {
		my $stat = stat($self->{_fh});
		if (! $self->{_state}->has_rolled($stat)) {
			$self->{_fh}->seek($self->{_state}->offset, 0);
		} else {
			$self->{_state}->set_stat($stat);
			$self->{_state}->set_line_number(0);
		}
		
		my $buf = $self->{_fh}->getline;
		if (defined $buf && $buf =~ m/ \n $/x) {
			$self->{_eof_count} = 0;
			my $stat = stat($self->{_fh});
			$self->{_state}->set_stat($stat);
			$self->{_state}->set_offset($self->{_fh}->tell);
			$self->{_state}->inc_line_number;
			$line = $buf;
			chomp $line;
		} elsif ($self->{_fh}->eof && 
			$self->{_eof_count} + 1 < $self->{_eof_count_max}) {
			$self->{_eof_count} ++;
			$self->{_fh}->seek($self->{_state}->offset, 0);
		} else {
			undef $self->{_fh};
			$self->{_eof_count} = 0;
		}
	}
	
	return $line;
}



sub state {
	my ($self) = @_;
	
	return $self->{_state};
}



1;

