package SOCC::nagios_logwatch::Tail::FileState;

use 5.006001;
use strict;
use warnings;
use fields qw(_dev _inode _offset _size _line_number _path);



sub new_string {
	my ($class, $string) = @_;
	
	my $self;
	if ( $string =~ m/^ FileState \s+
		(\d+) \s+ #dev
		(\d+) \s+ #inode
		(\d+) \s+ #offset
		(\d+) \s+ #size
		(\d+) \s+ #line number
		(.+) #path
		/x) {
		$self = fields::new($class);
		$self->{_dev} = $1;
		$self->{_inode} = $2;
		$self->{_offset} = $3;
		$self->{_size} = $4;
		$self->{_line_number} = $5;
		$self->{_path} = $6;
	}
	
	return $self;
}



sub new_path {
	my ($class, $path) = @_;
	
	my $self = fields::new($class);
	$self->{_dev} = 0;
	$self->{_inode} = 0;
	$self->{_offset} = 0;
	$self->{_size} = 0;
	$self->{_line_number} = 0;
	$self->{_path} = $path;
	
	return $self;
}



sub to_string {
	my ($self) = @_;
	
	return "FileState " .
		$self->{_dev} . " " .
		$self->{_inode} . " " .
		$self->{_offset} . " " .
		$self->{_size} . " " .
		$self->{_line_number} . " " .
		$self->{_path};
}



sub set_stat {
	my ($self, $stat_obj) = @_;
	
	$self->{_dev} = $stat_obj->dev;
	$self->{_inode} = $stat_obj->ino;
	$self->{_size} = $stat_obj->size;
}



sub set_offset {
	my ($self, $offset) = @_;
	
	$self->{_offset} = $offset;
}



sub set_line_number {
	my ($self, $line_number) = @_;
	
	$self->{_line_number} = $line_number;
}



sub inc_line_number  {
	my ($self) = @_;
	
	$self->{_line_number} ++;
}



sub has_rolled {
	my ($self, $stat) = @_;
	
	my $has_rolled =
		$self->{_dev} != $stat->dev ||
		$self->{_inode} != $stat->ino ||
		$self->{_size} > $stat->size;
	return $has_rolled;
}



sub offset {
	my ($self) = @_;
	
	return $self->{_offset};
}



sub line_number {
	my ($self) = @_;
	
	return $self->{_line_number};
}



sub path {
	my ($self) = @_;
	
	return $self->{_path};
}



1;

